@@ -60,7 +60,9 @@ class Rate:
             )
             targets = "substrates, products or modifiers"
         else:
-            difference = set(self.dynamic_variables).difference(self.substrates + self.modifiers)
+            difference = set(self.dynamic_variables).difference(
+                self.substrates + self.modifiers
+            )
             targets = "substrates or modifiers"
         if difference:
             warnings.warn(
@@ -74,7 +76,9 @@ class Rate:
         else:
             targets = "substrates, modifiers or parameters"
         if difference:
-            warnings.warn(f"Supplied args {difference} for rate {self.name} that aren't in {targets}")
+            warnings.warn(
+                f"Supplied args {difference} for rate {self.name} that aren't in {targets}"
+            )
 
     def check_consistency(self) -> None:
         """Check if args and arity of the rate are ok."""
@@ -138,7 +142,9 @@ class RateMixin(ParameterMixin, CompoundMixin, BaseModel):
     """Mixin adding rate functions."""
 
     def __init__(
-        self, rates: dict[str, Rate] | None = None, functions: dict[str, Callable[..., float]] | None = None
+        self,
+        rates: dict[str, Rate] | None = None,
+        functions: dict[str, Callable[..., float]] | None = None,
     ) -> None:
         self.rates: Dict[str, Rate] = {}
         self.functions: Dict[str, Callable[..., float]] = {}
@@ -308,7 +314,9 @@ class RateMixin(ParameterMixin, CompoundMixin, BaseModel):
         if check_consistency:
             self._check_rate_consistency(rate)
 
-    def add_rates(self, rates: Dict[str, Any], meta_info: Optional[Dict[str, Any]] = None) -> None:
+    def add_rates(
+        self, rates: Dict[str, Any], meta_info: Optional[Dict[str, Any]] = None
+    ) -> None:
         """Add multiple rates to the model.
 
         See Also
@@ -522,7 +530,9 @@ class RateMixin(ParameterMixin, CompoundMixin, BaseModel):
         fluxes = {}
         for name, rate in self.rates.items():
             try:
-                fluxes[name] = np.atleast_1d(rate.function(*(args[arg] for arg in rate.args)))
+                fluxes[name] = np.atleast_1d(
+                    rate.function(*(args[arg] for arg in rate.args))
+                )
             except KeyError as e:
                 raise KeyError(f"Could not find argument {e} for rate {name}") from e
         return fluxes
@@ -540,7 +550,9 @@ class RateMixin(ParameterMixin, CompoundMixin, BaseModel):
             function_strings.append(function_code)
         return "\n".join(sorted(function_strings))
 
-    def _generate_rates_source_code(self, *, include_meta_info: bool = True) -> Tuple[str, str]:
+    def _generate_rates_source_code(
+        self, *, include_meta_info: bool = True
+    ) -> Tuple[str, str]:
         """Generate modelbase source code for rates.
 
         See Also
