@@ -105,7 +105,9 @@ class _BaseSimulator(Generic[BASE_MODEL_TYPE], ABC):
         if isinstance(normalise, (int, float)):
             return [i / normalise for i in split_array]
         if len(normalise) == len(split_array):
-            return [i / np.reshape(j, (len(i), 1)) for i, j in zip(split_array, normalise)]
+            return [
+                i / np.reshape(j, (len(i), 1)) for i, j in zip(split_array, normalise)
+            ]
 
         results = []
         start = 0
@@ -120,7 +122,9 @@ class _BaseSimulator(Generic[BASE_MODEL_TYPE], ABC):
     def _test_run(self) -> None:
         """Perform a test step of the simulation in Python to get proper error handling."""
 
-    def _save_simulation_results(self, *, time: Array, results: Array, skipfirst: bool) -> None:
+    def _save_simulation_results(
+        self, *, time: Array, results: Array, skipfirst: bool
+    ) -> None:
         if self.time is None or self.results is None:
             self.time = [time]
             self.results = [results]
@@ -207,7 +211,9 @@ class _BaseSimulator(Generic[BASE_MODEL_TYPE], ABC):
             return None, None
         time_array = np.array(time)
         results_array = np.array(results)
-        self._save_simulation_results(time=time_array, results=results_array, skipfirst=True)
+        self._save_simulation_results(
+            time=time_array, results=results_array, skipfirst=True
+        )
         return time_array, results_array
 
     def simulate_to_steady_state(
@@ -230,7 +236,9 @@ class _BaseSimulator(Generic[BASE_MODEL_TYPE], ABC):
             return None, None
         time_array = np.array([time])
         results_array = np.array([results])
-        self._save_simulation_results(time=time_array, results=results_array, skipfirst=False)
+        self._save_simulation_results(
+            time=time_array, results=results_array, skipfirst=False
+        )
         return time_array, results_array
 
     @overload
@@ -263,7 +271,9 @@ class _BaseSimulator(Generic[BASE_MODEL_TYPE], ABC):
 
         results = self.results.copy()
         if normalise is not None:
-            results = self._normalise_split_array(split_array=results, normalise=normalise)
+            results = self._normalise_split_array(
+                split_array=results, normalise=normalise
+            )
         if concatenated:
             return np.concatenate(results, axis=0)  # type: ignore
         return results
@@ -377,12 +387,16 @@ class _BaseSimulator(Generic[BASE_MODEL_TYPE], ABC):
             Output file type. Json or pickle.
         """
         if self.time is None or self.results is None:
-            raise ValueError("Cannot save results, since none are stored in the simulator")
+            raise ValueError(
+                "Cannot save results, since none are stored in the simulator"
+            )
 
         res = cast(
             Dict[str, Array], self.get_results_dict(concatenated=True)
         )  # cast is just typing annotation
-        time = cast(Array, self.get_time(concatenated=True))  # cast is just typing annotation
+        time = cast(
+            Array, self.get_time(concatenated=True)
+        )  # cast is just typing annotation
         res["time"] = time
 
         res = {k: v.tolist() for k, v in res.items()}
@@ -435,7 +449,9 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         results: Optional[List[Array]] = None,
         parameters: List[Dict[str, float]] | None = None,
     ) -> None:
-        _BaseSimulator.__init__(self, model=model, integrator=integrator, y0=y0, time=time, results=results)
+        _BaseSimulator.__init__(
+            self, model=model, integrator=integrator, y0=y0, time=time, results=results
+        )
         self.full_results: Optional[List[Array]] = None
         self.fluxes: Optional[List[Array]] = None
         self.simulation_parameters = parameters
@@ -503,13 +519,17 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
 
     def update_parameter(self, parameter_name: str, parameter_value: float) -> None:
         """Update a model parameter."""
-        self.model.update_parameter(parameter_name=parameter_name, parameter_value=parameter_value)
+        self.model.update_parameter(
+            parameter_name=parameter_name, parameter_value=parameter_value
+        )
 
     def update_parameters(self, parameters: Dict[str, float]) -> None:
         """Update model parameters."""
         self.model.update_parameters(parameters=parameters)
 
-    def _save_simulation_results(self, *, time: Array, results: Array, skipfirst: bool) -> None:
+    def _save_simulation_results(
+        self, *, time: Array, results: Array, skipfirst: bool
+    ) -> None:
         super()._save_simulation_results(time=time, results=results, skipfirst=skipfirst)
         if self.simulation_parameters is None:
             self.simulation_parameters = []
@@ -817,7 +837,9 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         concatenated: bool = True,
     ) -> Optional[Union[Dict[str, Array], List[Dict[str, Array]]]]:
         """Get simulation results and derived compounds."""
-        full_results = self.get_full_results_array(normalise=normalise, concatenated=concatenated)
+        full_results = self.get_full_results_array(
+            normalise=normalise, concatenated=concatenated
+        )
         if full_results is None:
             return None
         all_compounds = self.model.get_all_compounds()
@@ -859,7 +881,9 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         concatenated: bool = True,
     ) -> Optional[Union[pd.DataFrame, List[pd.DataFrame]]]:
         """Get simulation results and derived compounds."""
-        full_results = self.get_full_results_array(normalise=normalise, concatenated=concatenated)
+        full_results = self.get_full_results_array(
+            normalise=normalise, concatenated=concatenated
+        )
         time = self.get_time(concatenated=concatenated)
         if full_results is None or time is None:
             return None
@@ -867,7 +891,10 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
 
         if concatenated:
             return pd.DataFrame(data=full_results, index=time, columns=all_compounds)
-        return [pd.DataFrame(data=res, index=t, columns=all_compounds) for t, res in zip(time, full_results)]
+        return [
+            pd.DataFrame(data=res, index=t, columns=all_compounds)
+            for t, res in zip(time, full_results)
+        ]
 
     @overload
     def get_variable(  # type: ignore
@@ -912,7 +939,9 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         -------
         results : numpy.array
         """
-        full_results_dict = self.get_full_results_dict(normalise=normalise, concatenated=concatenated)
+        full_results_dict = self.get_full_results_dict(
+            normalise=normalise, concatenated=concatenated
+        )
         if full_results_dict is None:
             return None
         if concatenated:
@@ -957,7 +986,9 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         concatenated: bool = True,
     ) -> Union[Array, List[Array]]:
         """Get simulation results for a specific variable."""
-        full_results_df = self.get_full_results_df(normalise=normalise, concatenated=concatenated)
+        full_results_df = self.get_full_results_df(
+            normalise=normalise, concatenated=concatenated
+        )
         if concatenated:
             full_results_df = cast(pd.DataFrame, full_results_df)
             return full_results_df.loc[:, variables].values  # type: ignore
@@ -1003,7 +1034,9 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         concentrations = dict(s.get_full_results_df(concatenated=True).iloc[-1])  # type: ignore
         return parameter_value, concentrations, fluxes  # type: ignore
 
-    def _scan_threading(self, parameter_name: str, parameter_values: ArrayLike, worker: Callable) -> list:
+    def _scan_threading(
+        self, parameter_name: str, parameter_values: ArrayLike, worker: Callable
+    ) -> list:
         with tqdm(total=len(parameter_values), desc=parameter_name) as pbar:
             results = []
             for value in parameter_values:
@@ -1017,7 +1050,9 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         with tqdm(total=len(parameter_values), desc=parameter_name) as pbar:
             with futures.ProcessPoolExecutor() as executor:
                 results = []
-                for task in futures.as_completed((executor.submit(worker, i) for i in parameter_values)):
+                for task in futures.as_completed(
+                    (executor.submit(worker, i) for i in parameter_values)
+                ):
                     results.append(task.result())
                     pbar.update(1)
         return results
@@ -1096,7 +1131,10 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         for (i, conc, flux) in results:
             concentrations[i] = conc
             fluxes[i] = flux
-        return pd.DataFrame(concentrations).T.sort_index(), pd.DataFrame(fluxes).T.sort_index()
+        return (
+            pd.DataFrame(concentrations).T.sort_index(),
+            pd.DataFrame(fluxes).T.sort_index(),
+        )
 
     def parameter_scan_2d(
         self,
@@ -1110,7 +1148,9 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         parameter_name1, parameter_values1 = p1
         parameter_name2, parameter_values2 = p2
         original_pars = self.model.parameters.copy()
-        for value in tqdm(parameter_values2, total=len(parameter_values2), desc=parameter_name2):
+        for value in tqdm(
+            parameter_values2, total=len(parameter_values2), desc=parameter_name2
+        ):
             self.update_parameter(parameter_name2, value)
             cs[value] = self.parameter_scan(
                 parameter_name1,
@@ -1135,7 +1175,9 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         parameter_name1, parameter_values1 = p1
         parameter_name2, parameter_values2 = p2
         original_pars = self.model.parameters.copy()
-        for value in tqdm(parameter_values2, total=len(parameter_values2), desc=parameter_name2):
+        for value in tqdm(
+            parameter_values2, total=len(parameter_values2), desc=parameter_name2
+        ):
             self.update_parameter(parameter_name2, value)
             c, v = self.parameter_scan_with_fluxes(
                 parameter_name1,
@@ -1168,7 +1210,9 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         title_kwargs: Dict[str, Any] | None = None,
     ) -> Tuple[Optional[Figure], Optional[Axis]]:
         compounds = self.model.get_compounds()
-        y = cast(pd.DataFrame, self.get_full_results_df(normalise=normalise, concatenated=True))
+        y = cast(
+            pd.DataFrame, self.get_full_results_df(normalise=normalise, concatenated=True)
+        )
         if y is None:
             return None, None
         fig, ax = plot(
@@ -1213,7 +1257,9 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         title_kwargs: Dict[str, Any] | None = None,
     ) -> Tuple[Optional[Figure], Optional[Axis]]:
         compounds = self.model.get_compounds()
-        y = cast(pd.DataFrame, self.get_full_results_df(normalise=normalise, concatenated=True))
+        y = cast(
+            pd.DataFrame, self.get_full_results_df(normalise=normalise, concatenated=True)
+        )
         if y is None:
             return None, None
         fig, ax = plot(
@@ -1261,7 +1307,9 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         title_kwargs: Dict[str, Any] | None = None,
     ) -> Tuple[Optional[Figure], Optional[Axis]]:
         compounds = self.model.get_derived_compounds()
-        y = cast(pd.DataFrame, self.get_full_results_df(normalise=normalise, concatenated=True))
+        y = cast(
+            pd.DataFrame, self.get_full_results_df(normalise=normalise, concatenated=True)
+        )
         if y is None:
             return None, None
         return plot(
@@ -1302,7 +1350,9 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         title_kwargs: Dict[str, Any] | None = None,
     ) -> Tuple[Optional[Figure], Optional[Axis]]:
         compounds = self.model.get_all_compounds()
-        y = cast(pd.DataFrame, self.get_full_results_df(normalise=normalise, concatenated=True))
+        y = cast(
+            pd.DataFrame, self.get_full_results_df(normalise=normalise, concatenated=True)
+        )
         if y is None:
             return None, None
         return plot(
@@ -1343,7 +1393,9 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         label_kwargs: Dict[str, Any] | None = None,
         title_kwargs: Dict[str, Any] | None = None,
     ) -> Tuple[Optional[Figure], Optional[Axis]]:
-        y = cast(pd.DataFrame, self.get_full_results_df(normalise=normalise, concatenated=True))
+        y = cast(
+            pd.DataFrame, self.get_full_results_df(normalise=normalise, concatenated=True)
+        )
         if y is None:
             return None, None
         return plot(
@@ -1393,7 +1445,9 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         --------
         >>> plot_grid([["x1", "x2"], ["x3", "x4]])
         """
-        y = cast(pd.DataFrame, self.get_full_results_df(normalise=normalise, concatenated=True))
+        y = cast(
+            pd.DataFrame, self.get_full_results_df(normalise=normalise, concatenated=True)
+        )
         if y is None:
             return None, None
         plot_groups = [(y.loc[:, compounds].values,) for compounds in compound_groups]
@@ -1715,7 +1769,9 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         if fluxes is None:
             return None, None
         fluxes = cast(pd.DataFrame, fluxes)
-        plot_groups = [(cast(Array, fluxes.loc[:, group].values),) for group in rate_groups]
+        plot_groups = [
+            (cast(Array, fluxes.loc[:, group].values),) for group in rate_groups
+        ]
         return plot_grid(
             plot_groups=plot_groups,  # type: ignore
             legend_groups=rate_groups,
